@@ -12,7 +12,6 @@ MODULE gipaw_module
   ! ... This module contains the variables used for GIPAW calculations
   !
   USE kinds, ONLY : DP
-  USE constants, ONLY : a0_to_cm => bohr_radius_cm
   USE parameters, ONLY : npk, ntypx, lmaxx
 
   IMPLICIT NONE
@@ -83,7 +82,6 @@ MODULE gipaw_module
 
   !<apsi>
   CHARACTER(256) :: file_reconstruction ( ntypx )
-  LOGICAL :: read_recon_in_paratec_fmt
   REAL(dp) :: rc(ntypx,0:lmaxx)
   COMPLEX(dp), ALLOCATABLE :: paw_becp2 ( :, : )
   REAL(dp), ALLOCATABLE, DIMENSION ( :, : ) :: lx, ly, lz
@@ -120,7 +118,6 @@ CONTAINS
     INTEGER :: ios
     NAMELIST /inputgipaw/ job, prefix, tmp_dir, conv_threshold, &
                          q_gipaw, iverbosity, filcurr, filfield, &
-                         read_recon_in_paratec_fmt, &
                          file_reconstruction, use_nmr_macroscopic_shape, &
                          nmr_macroscopic_shape, spline_ps, isolve, &
                          q_efg, hfi_output_unit, hfi_isotope, &
@@ -141,7 +138,6 @@ CONTAINS
     iverbosity = 0
     filcurr = ' '
     filfield = ' '
-    read_recon_in_paratec_fmt = .FALSE.
     file_reconstruction ( : ) = " "
     use_nmr_macroscopic_shape = .TRUE.
     nmr_macroscopic_shape = 2.0_dp / 3.0_dp
@@ -172,30 +168,30 @@ CONTAINS
   SUBROUTINE gipaw_bcast_input
 #ifdef __MPI
     USE mp,            ONLY : mp_bcast
+    USE mp_world,      ONLY : world_comm
     USE io_files,      ONLY : prefix, tmp_dir
     USE us,            ONLY : spline_ps
     implicit none
     integer :: root = 0
-    call mp_bcast(job, root)
-    call mp_bcast(prefix, root)
-    call mp_bcast(tmp_dir, root)
-    call mp_bcast(conv_threshold, root)
-    call mp_bcast(q_gipaw, root)
-    call mp_bcast(iverbosity, root)
-    call mp_bcast(filcurr, root)
-    call mp_bcast(filfield, root)
-    call mp_bcast(read_recon_in_paratec_fmt, root)
-    call mp_bcast(file_reconstruction, root)
-    call mp_bcast(use_nmr_macroscopic_shape, root)
-    call mp_bcast(nmr_macroscopic_shape, root)
-    call mp_bcast(spline_ps, root)
-    call mp_bcast(isolve, root)
-    call mp_bcast ( hfi_output_unit, root )
-    call mp_bcast ( hfi_isotope, root )
-    call mp_bcast ( hfi_nuclear_g_factor, root )
-    call mp_bcast ( radial_integral_splines, root )
-    CALL mp_bcast ( hfi_via_reconstruction_only, root )
-    CALL mp_bcast ( hfi_extrapolation_npoints, root )
+    call mp_bcast(job, root, world_comm)
+    call mp_bcast(prefix, root, world_comm)
+    call mp_bcast(tmp_dir, root, world_comm)
+    call mp_bcast(conv_threshold, root, world_comm)
+    call mp_bcast(q_gipaw, root, world_comm)
+    call mp_bcast(iverbosity, root, world_comm)
+    call mp_bcast(filcurr, root, world_comm)
+    call mp_bcast(filfield, root, world_comm)
+    call mp_bcast(file_reconstruction, root, world_comm)
+    call mp_bcast(use_nmr_macroscopic_shape, root, world_comm)
+    call mp_bcast(nmr_macroscopic_shape, root, world_comm)
+    call mp_bcast(spline_ps, root, world_comm)
+    call mp_bcast(isolve, root, world_comm)
+    call mp_bcast(hfi_output_unit, root, world_comm)
+    call mp_bcast(hfi_isotope, root, world_comm)
+    call mp_bcast(hfi_nuclear_g_factor, root, world_comm)
+    call mp_bcast(radial_integral_splines, root, world_comm)
+    CALL mp_bcast(hfi_via_reconstruction_only, root, world_comm)
+    CALL mp_bcast(hfi_extrapolation_npoints, root, world_comm)
 #endif
   END SUBROUTINE gipaw_bcast_input
 
@@ -236,50 +232,36 @@ CONTAINS
   !-----------------------------------------------------------------------
   SUBROUTINE gipaw_openfil
     USE io_global,        ONLY : stdout
-    USE basis,            ONLY : natomwfc, starting_wfc
     USE wvfct,            ONLY : nbnd, npwx
-    USE ldaU,             ONLY : lda_plus_U
-    USE klist,            ONLY : nks
-    USE io_files,         ONLY : prefix, iunat, iunsat, iunwfc, iunigk, &
-                                 nwordwfc, nwordatwfc, tmp_dir, wfc_dir,&
-                                 diropn, seqopn
+    USE ldaU,             ONLY : lda_plus_U, nwfcU
+    USE io_files,         ONLY : prefix, iunhub, iunwfc, iunigk, &
+                                 nwordwfcU, nwordwfc, seqopn
     USE noncollin_module, ONLY : npol
-    USE mp_global,        ONLY : kunit
     USE buffers,          ONLY : open_buffer
     USE control_flags,    ONLY : io_level
     IMPLICIT NONE
     LOGICAL            :: exst
-    ! ... nwordwfc is the record length (IN COMPLEX WORDS)
+    !
+    ! ... nwordwfc is the record length (IN REAL WORDS)
     ! ... for the direct-access file containing wavefunctions
+    ! ... io_level > 0 : open a file; io_level <= 0 : open a buffer
+    !
     nwordwfc = nbnd*npwx*npol
-
-    ! ... iunwfc=10: read/write wfc from/to file
-    ! ... iunwfc=-1: copy wfc to/from RAM
-    IF ( io_level > 0 ) THEN
-      iunwfc = 10
-    ELSE
-      iunwfc = -1
-    END IF
-    CALL open_buffer( iunwfc, 'wfc', nwordwfc, nks, exst )
+    CALL open_buffer( iunwfc, 'wfc', nwordwfc, io_level, exst )
 
     ! ... Needed for LDA+U
-    ! ... iunat  contains the (orthogonalized) atomic wfcs
-    ! ... iunsat contains the (orthogonalized) atomic wfcs * S
-    ! ... iunocc contains the atomic occupations computed in new_ns
-    ! ... it is opened and closed for each reading-writing operation
-    nwordatwfc = 2*npwx*natomwfc*npol
-    IF ( lda_plus_u ) then
-       CALL diropn( iunat,  'atwfc',  nwordatwfc, exst )
-       CALL diropn( iunsat, 'satwfc', nwordatwfc, exst )
-    END IF
-
+    ! ... iunhub contains the (orthogonalized) atomic wfcs * S
+    !
+    nwordwfcU = npwx*nwfcU*npol
+    IF ( lda_plus_u ) &
+       CALL open_buffer( iunhub, 'hub', nwordwfcU, io_level, exst )
+    !
     ! ... iunigk contains the number of PW and the indices igk
-    ! ... Note that unit 15 is reserved for error messages
+    ! ... 
     CALL seqopn( iunigk, 'igk', 'UNFORMATTED', exst )
+    !
     RETURN
   END SUBROUTINE gipaw_openfil
-
-
   !-----------------------------------------------------------------------
   ! Print timings
   !-----------------------------------------------------------------------
@@ -341,7 +323,7 @@ CONTAINS
     USE klist,         ONLY : xk, degauss, ngauss, nks, nelec
     USE constants,     ONLY : degspin, pi
     USE paw_gipaw,     ONLY : paw_recon, paw_nkb, paw_vkb, paw_becp, &
-                              read_recon, read_recon_paratec, set_paw_upf
+                              read_recon, set_paw_upf
     USE symm_base,     ONLY : nsym, s
     USE uspp_param,    ONLY : upf
     USE mp_global,     ONLY : inter_pool_comm
@@ -394,22 +376,9 @@ CONTAINS
 
     ! Read in qe format
     DO nt = 1, ntyp
-       IF ( read_recon_in_paratec_fmt ) THEN
-
-          ! Read in paratec format
-          CALL read_recon_paratec ( file_reconstruction(nt), nt, &
-               paw_recon(nt), vloc_set )
-          IF ( .NOT. vloc_set .AND. job == "g-tensor" ) THEN
-             CALL errore ( "gipaw_setup", &
-                  "no local potential set in read_recon_paratec", 1 )
-             stop
-          END IF
-
-       ELSE
-          CALL set_paw_upf (nt, upf(nt))
-          CALL read_recon ( file_reconstruction(nt), nt, paw_recon(nt) )
-          !!!paw_recon(nt)%paw_nbeta = 0
-       END IF
+       CALL set_paw_upf (nt, upf(nt))
+       CALL read_recon ( file_reconstruction(nt), nt, paw_recon(nt) )
+       !!!paw_recon(nt)%paw_nbeta = 0
     END DO
 
     if ( iverbosity > 20 ) then
